@@ -16,9 +16,9 @@ try:
 except ImportError:
     has_torch = False
 
-seed = 7
-random.seed(seed)
-np.random.seed(seed)
+# seed = 7
+# random.seed(seed)
+# np.random.seed(seed)
 
 
 class ELSPEnv(gym.Env):
@@ -138,9 +138,9 @@ class ELSPEnv(gym.Env):
         return s1, s2
 
 
-env = ELSPEnv(env_path="../elsp_env_00001", cfg_path="..", demand_scale=1)
 if __name__ == "__main__":
     time_calculator.st("main")
+    env = ELSPEnv(env_path="../elsp_env_00001", cfg_path="..", demand_scale=1)
 
 
     def log_inf(_inf):
